﻿#The defaults on parameter values on these functions should either be modified to fit your environment or should be 
#passed in when calling the functions.
#i.e.
#Create-UeVAgentCI -AgentSettings "PathToYour.XML" -Site "ABC" -CabFile "PathToYour.CAB" 
#Create-UeVTemplatesBaseline -TemplateFolder "c:\Your\Tempates\Here" -Site "ABC" -CabFile "PathToYour.CAB"
#Connect-CM12 -SiteCode "ABC" -SiteServer "your.fqdn.site.server" -PathToPSD1 "c:\path to your console install\bin\"

Function Create-UeVTemplatesBaseline {
    <#
    .SYNOPSIS
    Create UeV Templates Baseline File
    .DESCRIPTION
    Looks to provided folder to get all xml files added to a SCCM baseline object.
    .EXAMPLE
    Create-UeVTemplateBaseline -TemplateFolder "c:\uev\templates" -Site "OMA" -CabFile "c:\uev\UeVCMBaseline.cab"
    .PARAMETER TemplateFolder
    Folder location of UeV Template (xml)
    .PARAMETER Site
    The ConfigMgr Site
    .PARAMETER CabFile
    The Cab file path to output to.  This file will be created.
    #>
    [CmdletBinding()]
    param
    (
        [Parameter(Mandatory=$False,
        ValueFromPipeline=$True,
        ValueFromPipelineByPropertyName=$True,
        HelpMessage='Where are your Uev Templates?')]
        [string[]]$TemplateFolder="c:\uev\templates",
        [string]$Site = 'OMA',
        [string]$CabFile = "c:\Uev\UeVCMBaseline.cab"
    )
    begin {

    }
    process {
        if(Test-Path $TemplateFolder){
            $templates = Get-ChildItem -Path $templateFolder -Filter "*.xml"
            $command = "C:\Program Files (x86)\Microsoft User Experience Virtualization\ConfigPack\UevTemplateBaselineGenerator.exe"
            $formattedInput = ""
            $counter = 0;
            write-verbose "Using Template Folder - $templateFolder"
            Write-Verbose "Looking for XML files in $TemplateFolder"
            foreach ($template in $templates){ #begin building "Register" argument.  
                if($counter -eq 0){ #first one
                    $formattedInput = $template.Name
                }
                else{
                    $formattedInput = $formattedInput + "," + [string]$template.Name
                }
                $filename = $Template.Name
                write-verbose "Found $filename"
                $counter++
            } #end building Register argument
            $fullCommand = "`"$command`"" +" -site " + $site + " -TemplateFolder `"" + $templateFolder + "`" -Register `"" + $formattedInput + "`" -CabFilePath `"" + $cabFile + "`""
            set-location c:\
            out-file -FilePath out.bat -InputObject $fullCommand -Encoding ascii |out-null
            write-verbose "Creating $CabFile"
            .\out.bat
            Connect-CM12 |out-null
            set-location $site`:\
            Write-Verbose "Importing Templates Baseline File"
            Import-CMBaseline -FileName $CabFile
            Write-Verbose "Import complete."
        }
        else{
            Write-Verbose "Template folder path not found"
            Write-Verbose $TemplateFolder
        }
    }   
}
function Connect-CM12 {
    [CmdletBinding()]
    param
    (
        [string]$SiteCode = 'OMA',
        [string]$SiteServer = "sccm2012ps.dev.dlx.com",
        [string]$PathToPSD1 = "C:\Program Files (x86)\Microsoft Configuration Manager\AdminConsole\bin\ConfigurationManager.psd1"
    )
    if(!(Get-Module ConfigurationManager)){
        import-module $PathToPSD1 -force
    }
    if ((get-psdrive DLX -erroraction SilentlyContinue | measure).Count -ne 1) {
        new-psdrive -Name $SiteCode -PSProvider "AdminUI.PS.Provider\CMSite" -Root $SiteServer
    }
}
function Create-UeVAgentCI {
    <#
    .SYNOPSIS
    Create UeV Agent CI File
    .DESCRIPTION
    Looks to provided XML document to create CI Cab file for UeV Agent settings.
    .EXAMPLE
    Create-UeVAgentCI -AgentSettings "c:\uev\UeVAgentConfiguration.xml" -Site "OMA" -CabFile "c:\uev\UeVCMAgentCI.cab"
    .PARAMETER AgentSettings
    Folder location of UeV Template (xml)
    .PARAMETER Site
    The ConfigMgr Site, aka OMA
    .PARAMETER CabFile
    The Cab file path to output to.  This file will be created.
    #>
    [CmdletBinding()]
    param
    (
        [Parameter(Mandatory=$False,
        ValueFromPipeline=$True,
        ValueFromPipelineByPropertyName=$True,
        HelpMessage='Where is the agent configuration XML?')]
        [string[]]$AgentSettings="c:\uev\UeVAgentConfiguration.xml",
        [string]$Site = 'OMA',
        [string]$CabFile = "c:\uev\UeVCMAgentCI.cab"
    )

    begin{
    }
    process{
        Write-Verbose "Using Agent Settings - $AgentSettings"
        $command = "`"c:\Program Files (x86)\Microsoft User Experience Virtualization\ConfigPack\UevAgentPolicyGenerator.exe`""
        set-location c:\
        $fullcommand = $command + " -Site $Site -CabFilePath $CabFile -ConfigurationFile $AgentSettings"
        out-file -FilePath "out.bat" -Encoding ascii -InputObject $fullcommand | out-null
        Write-Verbose "Creating CI file $CabFile"
        .\out.bat 
        Connect-CM12 |out-null
        set-location $site`:\
        write-verbose "Importing CMConfigurationItem"
        Import-CMConfigurationItem -FileName $CabFile 
        Write-Verbose "Import complete."
    }
}

Create-UeVAgentCI -verbose
Create-UeVTemplatesBaseline -verbose
